// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef QMOBIPOCKET_VERSION_H
#define QMOBIPOCKET_VERSION_H

#define QMOBIPOCKET_VERSION_STRING "3.0.0"
#define QMOBIPOCKET_VERSION_MAJOR 3
#define QMOBIPOCKET_VERSION_MINOR 0
#define QMOBIPOCKET_VERSION_PATCH 0
#define QMOBIPOCKET_VERSION ((3<<16)|(0<<8)|(0))

#endif
